# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bentoctl', 'bentoctl.cli', 'bentoctl.operator']

package_data = \
{'': ['*']}

install_requires = \
['GitPython==3.1.24',
 'PyYaml>=6,<7',
 'bentoml',
 'cerberus>=1,<2',
 'click>=7,<8',
 'cloup>=0.12,<0.13',
 'rich>=10,<11',
 'simple-term-menu==0.4.4']

entry_points = \
{'console_scripts': ['bentoctl = bentoctl.cli:bentoctl']}

setup_kwargs = {
    'name': 'bentoctl',
    'version': '1.0.0a1',
    'description': 'Command line tool for deploying ML models to the cloud.',
    'long_description': '<div align="center">\n  <h1>bentoctl</h1>\n  <i>Best way to deploy BentoML to the cloud.</i>\n  <p>\n    <img alt="PyPI" src="https://img.shields.io/pypi/v/bentoctl?style=flat-square">\n    <img alt="GitHub branch checks state" src="https://img.shields.io/github/checks-status/bentoml/bentoctl/main?style=flat-square">\n    <img alt="Codecov" src="https://img.shields.io/codecov/c/github/bentoml/bentoctl?style=flat-square">\n</p>\n</div>\n\n<br>\n\nbentoctl is a command-line tool that uses easy and approachable YAML syntax to deploy Bento to the cloud.\nIt supports multiple cloud providers, including AWS, Azure, Google Cloud, and more. It is completely extensible with\noperators that can add more cloud providers, uses-cases and workflows.\n\n<div align="center">\n<img src="https://raw.githubusercontent.com/bentoml/bentoctl/master/demo.gif"/ alt="demo of bentoctl deploying to AWS-EC2"/>\n</div>\n\n## Quick Start\n\n### Installing\n`pip install bentoctl`\n\nTo activate tab completion for you shell, source the script in `bentoctl/completion`.\nFor More info please check [click\'s documentation](https://click.palletsprojects.com/en/8.0.x/shell-completion/)\n\n\n### Add AWS EC2 operator\n\n`bentoctl operators add aws-ec2`\n\n\n### Deploy Bento to EC2\n\nUse the interactive deployment helper. This will generate a deployment YAML file and will then deploy the Bento to the cloud.\n```\n$ bentoctl deploy\n```\n\n`bentoctl deploy` also accepts deployment configuration file.\n\nSave the following configuration file to `deployment_config.yaml`\n```yaml\napi_version: v1\nmetadata:\n  name: my-bento-deployment\n  operator: aws-ec2\nspec:\n  bento: iris_classifier:latest\n  region: us-west-1\n  instance_type: t2.micro\n  ami_id: /aws/service/ami-amazon-linux-latest/amzn2-ami-hvm-x86_64-gp2\n  enable_gpus: False\n```\nCall deploy command\n```\n$ bentoctl deploy deployment_config.yaml\n```\n\n### Delete deployment\n```\n$ bentoctl delete deployment_config.yaml\n```\n\n## Features:\n\n* Supports multiple cloud providers: AWS, Azure, Google Cloud, and more.\n* Manages the lifecycle of the BentoML deployment.\n* Minimal configuration\n* Optimized for CI/CD workflow\n* Built with optimization and best practices\n* Extensible with operators. Extends or modifies the cloud services and workflow via operators.\n',
    'author': 'bentoml.org',
    'author_email': 'contact@bentoml.ai',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bentoml/bentoctl',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
